#!/bin/sh
# 4.20  damonitorsTEC.sh, tec 
#
# Licensed Materials - Property of IBM
#
#
# (C) Copyright IBM Corp. 2003, 2004 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp
#
#  Version 4.20
#
#  This simple Bourne shell script loads all necesary items 
#  for Monitors.
#
#  ./damonitorsTEC.sh <Rule Base Name> <Rule Base Directory> <Source Rule Base>
#
#  Source Rule Base is Default if not provided
#
#  This script must be run on your TEC Server

# Usage statement
if [ $# -lt 3 ] ; then
        echo "Usage: $0 <Rule Base Name> <Rule Base Directory> <Source Rule Base>"
	echo "       Your Source rule base MUST have the Tmw2k.baroc already loaded."
        exit 1
fi

source_rb="$3"

echo "Creating Rule Base $1 in $2"
wrb -crtrb -path "$2" "$1"

echo "Copying Rule Base $source_rb to $1"
wrb -cprb -classes -rulesets -rulepacks -targets -delete "$source_rb" "$1"

echo "Importing Director Monitoring Classes into $1"
wrb -imprbclass HTTPCheck_sh.baroc "$1"
wrb -imprbclass IBMPSG_Chassis.baroc "$1"
wrb -imprbclass IBMPSG_PhysicalNetworkAdapter.baroc "$1"
wrb -imprbclass IBMPSG_PortableBattery.baroc "$1"
wrb -imprbclass IBMPSG_Tachometer.baroc "$1"
wrb -imprbclass IBMPSG_TemperatureSensor.baroc "$1"
wrb -imprbclass IBMPSG_VoltageSensor.baroc "$1"
wrb -imprbclass SNMPCheck_sh.baroc "$1"
wrb -imprbclass IBMPSG_ServeRAIDOverallStatus.baroc "$1"
wrb -imprbclass IBMPSG_StorageFailurePredictionSettings.baroc "$1"
wrb -imprbclass IBMPSG_PhysicalMemory.baroc "$1"
wrb -imprbclass IBMPSG_Processor.baroc "$1"

echo "Deleting target"
wrb -delrbtarget EventServer "$1"

echo "Compiling Rule Base $1"
wrb -comprules "$1"

echo "Loading Rule Base $1 into EventServer"
wrb -loadrb "$1"

echo "Restarting EventServer!"
wstopesvr
wstartesvr

echo "Director TEC Integration complete!"


