#!/bin/sh
#
# Licensed Materials - Property of IBM
#
#
# (C) Copyright IBM Corp. 2003, 2004 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp
#
#  Version 4.20
#
#  This simple Bourne shell script creates a query library
#  containing the Inventory queries. It must be run by
#  an administrator with proper TME authorization in the
#  appropriately configured TMR where the library must reside.
#  The following queries are created within the specified
#  query library (default is DIRECTOR_AGENT):
#
#     Alert On LAN Settings
#     Alert Standard Format Settings
#     AssetID
#     BIOS Details
#     Cache
#     CIM
#     IP Network Configuration
#     IPX Network Configuration
#     Firmware
#     FRU Service Numbers
#     Geographic Information
#     IBM Director Agent
#     Installed Director Agent
#     Lease Information
#     Memory Details
#     Network Details
#     Personalized Data
#     Port Connectors
#     Processor Details
#     Serial Number Information
#     SNMP Agent Configuration
#     System Board Configuration
#     System Enclosure
#     System Slots
#     User Details
#     Video Details
#     Warranty Information
#     ServeRAID Controllers
#     ServeRAID Disk Drives
#     ServeRAID Enclosures
#     ServeRAID Logical Drives
#     RAID Controllers
#     RAID Disk Drives
#     RAID Enclosures
#     RAID Logical Drives
#
#  ./dainv_query.sh <RIM Name> <PolicyRegionName> [QueryLibraryName]
#
# 'sleep 2' statements added as a workaround to query defect 
# to prevent transaction collisions.
#

# Usage statement
if [ $# -lt 2 ] ; then
        echo "Usage: $0 <RIM Name> <PolicyRegionName> [QueryLibraryName]"
        exit 1
fi

if [ $# -eq 3 ] ; then
	query_lib="$3"
else
	query_lib='DIRECTOR_AGENT_INV'
fi
   
echo "Creating query library $query_lib in $2..."
wcrtqlib "$2" "$query_lib"

echo "Creating query 'Alert On LAN Settings' in $query_lib..." 
wcrtquery -d "Alert On LAN Settings" -r "$1" -v UMA_VAlert_On_LAN_Settings \
   -c TME_OBJECT_LABEL \
   -c Retransmission_Interval \
   -c Polling_Interval \
   -c Heartbeat_Interval \
   -c Hardware_Version \
   -c Alert_Destination \
   -c Auto_Clear_Events \
   -c Heartbeat_Enabled \
   -c Hardware_Enabled \
   -c Watchdog_Interval \
   -c Watchdog_Enabled \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Alert On LAN Settings"
sleep 2

echo "Creating query 'Alert Standard Format Settings' in $query_lib..." 
wcrtquery -d "Alert Standard Format Settings" -r "$1" -v UMA_VAlert_Standard_Format_hhi \
   -c TME_OBJECT_LABEL \
   -c AlertDestinationAddress \
   -c MessageFormat \
   -c RetryCount \
   -c RetryInterval \
   -c ASFEnabled \
   -c PETsEnabled \
   -c HeartBeatsEnabled \
   -c RMCPEnabled \
   -c ASFWoLEnabled \
   -c FirmwareVersion \
   -c HeartbeatInterval \
   -c ASFSourceIP \
   -c MinPollingInterval \
   -c MinWatchdogResetValue \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Alert Standard Format Settings"
sleep 2

echo "Creating query 'AssetID' in $query_lib..." 
wcrtquery -d "AssetID" -r "$1" -v UMA_VAssetID \
   -c TME_OBJECT_LABEL \
   -c System_Name \
   -c System_Model \
   -c Product_Name \
   -c Deployment_Image_Profile \
   -c Deployment_Image_Date \
   -c LCCM_Image_Profile \
   -c LCCM_Image_Date \
   -c System_Serial_Number \
   -c System_GUID \
   -c System_Asset_Number \
   -c AssetID_Tag \
   -c Last_Inventoried \
   -c Purchase_Date \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "AssetID"
sleep 2

echo "Creating query 'BIOS Details' in $query_lib..." 
wcrtquery -d "BIOS Details" -r "$1" -v UMA_VBIOS_Details \
   -c TME_OBJECT_LABEL \
   -c BIOS_Manufacturer \
   -c BIOS_Version \
   -c BIOS_Release_Date \
   -c Supports_SMBIOS \
   -c SMBIOS_Major_Version \
   -c SMBIOS_Minor_Version \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "BIOS Details"
sleep 2

echo "Creating query 'Cache' in $query_lib..." 
wcrtquery -d "Cache" -r "$1" -v UMA_VCache \
   -c TME_OBJECT_LABEL \
   -c level_ \
   -c System_Cache_Size \
   -c System_Cache_Write_Policy \
   -c Socket_Designation \
   -c Cache_Location \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Cache"
sleep 2

echo "Creating query 'CIM' in $query_lib..." 
wcrtquery -d "CIM" -r "$1" -v UMA_VCIM \
   -c TME_OBJECT_LABEL \
   -c CIM_Version \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "CIM"
sleep 2

echo "Creating query 'Firmware' in $query_lib..." 
wcrtquery -d "Firmware" -r "$1" -v UMA_VFirmware \
   -c TME_OBJECT_LABEL \
   -c Name \
   -c BIOS_Manufacturer \
   -c Description \
   -c BIOS_Version \
   -c BuildNumber \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Firmware"
sleep 2

echo "Creating query 'FRU Service Numbers' in $query_lib..." 
wcrtquery -d "FRU Service Numbers" -r "$1" -v UMA_VFRU_Service_Numbers \
   -c TME_OBJECT_LABEL \
   -c Name \
   -c FRUNumber \
   -c IdentifyingNumber \
   -c Vendor \
   -c RevisionLevel \
   -c Description \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "FRU Service Numbers"
sleep 2

echo "Creating query 'Geographic Information' in $query_lib..." 
wcrtquery -d "Geographic Information" -r "$1" -v UMA_VGeographic_Information \
   -c TME_OBJECT_LABEL \
   -c Locale \
   -c Country_Code \
   -c OS_Language \
   -c Code_Set \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Geographic Information"
sleep 2

echo "Creating query 'IBM Director Agent' in $query_lib..." 
wcrtquery -d "IBM Director Agent" -r "$1" -v UMA_VIBM_UM_Services \
   -c TME_OBJECT_ID \
   -c TME_OBJECT_LABEL \
   -c Name \
   -c Version \
   -c Build_Number \
   -c HTTPD_Port \
   -c SNMP_Traps_Enabled \
   -c Trap_Destinations \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "IBM Director Agent"
sleep 2

echo "Creating query 'IP Network Configuration' in $query_lib..." 
wcrtquery -d "IP Network Configuration" -r "$1" -v UMA_VIP_Network_Configuration \
   -c TME_OBJECT_LABEL \
   -c IP_Address \
   -c IP_Subnet_Mask \
   -c IP_Gateway \
   -c DNS_Servers \
   -c DHCP_Enabled \
   -c DNS_Hostname \
   -c DNS_Domain \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "IP Network Configuration"
sleep 2

echo "Creating query 'IPX Network Configuration' in $query_lib..." 
wcrtquery -d "IPX Network Configuration" -r "$1" -v UMA_VIPX_Network_Configuration \
   -c TME_OBJECT_LABEL \
   -c IPX_Enabled \
   -c IPX_Frame_Type \
   -c IPX_Address \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "IPX Network Configuration"
sleep 2

echo "Creating query 'Lease Information' in $query_lib..." 
wcrtquery -d "Lease Information" -r "$1" -v UMA_VLease_Information \
   -c TME_OBJECT_LABEL \
   -c Lessor \
   -c Lease_Start_Date \
   -c Lease_End_Date \
   -c Lease_Term__months_ \
   -c Lease_Amount \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Lease Information"
sleep 2

echo "Creating query 'Memory Details' in $query_lib..." 
wcrtquery -d "Memory Details" -r "$1" -v UMA_VMemory_Details \
   -c TME_OBJECT_LABEL \
   -c Device_Locator \
   -c siz_ \
   -c Form_Factor \
   -c Type \
   -c Speed \
   -c Data_Width \
   -c Total_Width \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Memory Details"
sleep 2

echo "Creating query 'Network Details' in $query_lib..." 
wcrtquery -d "Network Details" -r "$1" -v UMA_VNetwork_Details \
   -c TME_OBJECT_LABEL \
   -c Network_Adapter \
   -c Network_Driver \
   -c MAC_Address \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Network Details"
sleep 2

echo "Creating query 'Personalized Data' in $query_lib..." 
wcrtquery -d "Personalized Data" -r "$1" -v UMA_VPersonalized_Data \
   -c TME_OBJECT_LABEL \
   -c Label1 \
   -c Data1 \
   -c Label2 \
   -c Data2 \
   -c Label3 \
   -c Data3 \
   -c Label4 \
   -c Data4 \
   -c Label5 \
   -c Data5 \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Personalized Data"
sleep 2

echo "Creating query 'Port Connectors' in $query_lib..." 
wcrtquery -d "Port Connectors" -r "$1" -v UMA_VPort_Connectors \
   -c TME_OBJECT_LABEL \
   -c Logical_Name \
   -c Internal_Ports \
   -c Connector_Type \
   -c Port_Type \
   -c Tag \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Port Connectors"
sleep 2

echo "Creating query 'Processor Details' in $query_lib..." 
wcrtquery -d "Processor Details" -r "$1" -v UMA_VProcessor_Details \
   -c TME_OBJECT_LABEL \
   -c Processor \
   -c Family \
   -c Clock_Speed \
   -c External_Clock_Speed \
   -c Max_Clock_Speed \
   -c Manufacturer \
   -c Processor_ID \
   -c Processor_Type \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Processor Details"
sleep 2

echo "Creating query 'Serial Number Information' in $query_lib..." 
wcrtquery -d "Serial Number Information" -r "$1" -v UMA_VSerial_Number_Information \
   -c TME_OBJECT_LABEL \
   -c Asset \
   -c Serial_Number \
   -c Manufacturer \
   -c Model \
   -c Type \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Serial Number Information"
sleep 2

echo "Creating query 'SNMP Agent Configuration' in $query_lib..." 
wcrtquery -d "SNMP Agent Configuration" -r "$1" -v UMA_VSNMP_Agent_Configuration \
   -c TME_OBJECT_LABEL \
   -c SNMP_Traps_Enabled \
   -c Trap_Destinations \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "SNMP Agent Configuration"
sleep 2

echo "Creating query 'System Board Configuration' in $query_lib..." 
wcrtquery -d "System Board Configuration" -r "$1" -v UMA_VSystem_Board_Configurac1d \
   -c TME_OBJECT_LABEL \
   -c String \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "System Board Configuration"
sleep 2

echo "Creating query 'System Enclosure' in $query_lib..." 
wcrtquery -d "System Enclosure" -r "$1" -v UMA_VSystem_Enclosure \
   -c TME_OBJECT_LABEL \
   -c Manufacturer \
   -c Type \
   -c Cabinet_Lock_Present \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "System Enclosure"
sleep 2

echo "Creating query 'System Slots' in $query_lib..." 
wcrtquery -d "System Slots" -r "$1" -v UMA_VSystem_Slots \
   -c TME_OBJECT_LABEL \
   -c Slot_Type \
   -c Slot_Data_Bus_Width \
   -c Supports_Hot_Plug \
   -c Current_Usage \
   -c SlotDesignation \
   -c Shared_Slot_Opening \
   -c Supports_PME_Signal \
   -c Tag \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "System Slots"
sleep 2

echo "Creating query 'User Details' in $query_lib..." 
wcrtquery -d "User Details" -r "$1" -v UMA_VUser_Details \
   -c TME_OBJECT_LABEL \
   -c User_Name \
   -c User_Phone \
   -c User_Department \
   -c User_Position \
   -c System_Location \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "User Details"
sleep 2

echo "Creating query 'Video Details' in $query_lib..." 
wcrtquery -d "Video Details" -r "$1" -v UMA_VVideo_Details \
   -c TME_OBJECT_LABEL \
   -c Manufacturer \
   -c Description \
   -c Current_Vertical_Resolution \
   -c Current_Horizontal_Resolution \
   -c Current_Number_of_Bits_per_Pix \
   -c Video_RAM_Memory_Size \
   -c Driver_Filename \
   -c Current_Refresh_Rate \
   -c Color_Depth \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Video Details"
sleep 2

echo "Creating query 'Warranty Information' in $query_lib..." 
wcrtquery -d "Warranty Information" -r "$1" -v UMA_VWarranty_Information \
   -c TME_OBJECT_LABEL \
   -c Warranty_Duration \
   -c Warranty_End_Date \
   -c Warranty_Cost \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Warranty Information"
sleep 2

echo "Creating query 'ServeRAID Controllers' in $query_lib..." 
wcrtquery -d "ServeRAID Controllers" -r "$1" -v UMA_VServeRAID_Controllers \
   -c TME_OBJECT_LABEL \
   -c DeviceID \
   -c Model \
   -c Manufacturer \
   -c Slot \
   -c BIOS_Version \
   -c Firmware_Version \
   -c Driver_Version \
   -c Stripe_Size \
   -c Initiator_IDs \
   -c Clustering \
   -c Cache_Battery_Status \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "ServeRAID Controllers"
sleep 2

echo "Creating query 'ServeRAID Disk Drives' in $query_lib..." 
wcrtquery -d "ServeRAID Disk Drives" -r "$1" -v UMA_VServeRAID_Disk_Drives \
   -c TME_OBJECT_LABEL \
   -c DeviceID \
   -c ChannelID \
   -c ControllerID \
   -c Firmware \
   -c Capacity \
   -c Manufacturer \
   -c Model \
   -c FRU \
   -c Serial_Number \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "ServeRAID Disk Drives"
sleep 2

echo "Creating query 'ServeRAID Enclosures' in $query_lib..." 
wcrtquery -d "ServeRAID Enclosures" -r "$1" -v UMA_VServeRAID_Enclosures \
   -c TME_OBJECT_LABEL \
   -c DeviceID \
   -c ChannelID \
   -c ControllerID \
   -c FirmwareLevel \
   -c Manufacturer \
   -c Model \
   -c Serial_Number \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "ServeRAID Enclosures"
sleep 2

echo "Creating query 'ServeRAID Logical Drives' in $query_lib..." 
wcrtquery -d "ServeRAID Logical Drives" -r "$1" -v UMA_VServeRAID_Logical_Drives \
   -c TME_OBJECT_LABEL \
   -c LogicalDriveID \
   -c ControllerID \
   -c ArrayID \
   -c RAID_Level \
   -c Data_Space \
   -c Install_Date \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "ServeRAID Logical Drives"
sleep 2

echo "Creating query 'RAID Controllers' in $query_lib..." 
wcrtquery -d "RAID Controllers" -r "$1" -v UMA_VRAID_Controllers \
   -c TME_OBJECT_LABEL \
   -c DeviceID \
   -c Model \
   -c Manufacturer \
   -c Slot \
   -c BIOS_Version \
   -c Firmware_Version \
   -c Driver_Version \
   -c Stripe_Size \
   -c Initiator_IDs \
   -c Clustering \
   -c Cache_Battery_Status \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "RAID Controllers"
sleep 2

echo "Creating query 'RAID Disk Drives' in $query_lib..." 
wcrtquery -d "RAID Disk Drives" -r "$1" -v UMA_VRAID_Disk_Drives \
   -c TME_OBJECT_LABEL \
   -c DeviceID \
   -c ChannelID \
   -c ControllerID \
   -c Firmware \
   -c Capacity \
   -c Manufacturer \
   -c Model \
   -c FRU \
   -c Serial_Number \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "RAID Disk Drives"
sleep 2

echo "Creating query 'RAID Enclosures' in $query_lib..." 
wcrtquery -d "RAID Enclosures" -r "$1" -v UMA_VRAID_Enclosures \
   -c TME_OBJECT_LABEL \
   -c DeviceID \
   -c ChannelID \
   -c ControllerID \
   -c Firmware_Level \
   -c Manufacturer \
   -c Model \
   -c Serial_Number \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "RAID Enclosures"
sleep 2

echo "Creating query 'RAID Logical Drives' in $query_lib..." 
wcrtquery -d "RAID Logical Drives" -r "$1" -v UMA_VRAID_Logical_Drives \
   -c TME_OBJECT_LABEL \
   -c LogicalDriveID \
   -c ControllerID \
   -c ArrayID \
   -c RAID_Level \
   -c Data_Space \
   -c Install_Date \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "RAID Logical Drives"
sleep 2
