#!/bin/sh
#  @(#)76    4.20  dainv_queries.sh, inventory, inventory_4.2  
#
# Licensed Materials - Property of IBM
#
#
# (C) Copyright IBM Corp. 2003, 2004 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp
#
#  Version 4.20
#
#  This simple Bourne shell script creates a query library
#  containing the Inventory queries. It must be run by
#  an administrator with proper TME authorization in the
#  appropriately configured TMR where the library must reside.
#  The following queries are created within the specified
#  query library (default is DIRECTOR_AGENT):
#
#     Alert On LAN Settings
#     Alert Standard Format Settings
#     AssetID
#     BIOS Details
#     Cache
#     CIM
#     IP Network Configuration
#     IPX Network Configuration
#     Firmware
#     FRU Service Numbers
#     Geographic Information
#     IBM Director Agent
#     Installed Director Agent
#     Lease Information
#     Memory Details
#     Network Details
#     Personalized Data
#     Port Connectors
#     Processor Details
#     Serial Number Information
#     SNMP Agent Configuration
#     System Board Configuration
#     System Enclosure
#     System Slots
#     User Details
#     Video Details
#     Warranty Information
#     ServeRAID Controllers
#     ServeRAID Disk Drives
#     ServeRAID Enclosures
#     ServeRAID Logical Drives
#     RAID Controllers
#     RAID Disk Drives
#     RAID Enclosures
#     RAID Logical Drives
#
#  ./dainv_query_db2.sh <RIM Name> <PolicyRegionName> [QueryLibraryName]
#
# 'sleep 2' statements added as a workaround to query defect 
# to prevent transaction collisions.
#

# Usage statement
if [ $# -lt 2 ] ; then
        echo "Usage: $0 <RIM Name> <PolicyRegionName> [QueryLibraryName]"
        exit 1
fi

if [ $# -eq 3 ] ; then
	query_lib="$3"
else
	query_lib='DIRECTOR_AGENT_INV'
fi

echo "Creating query library $query_lib in $2..."
wcrtqlib "$2" "$query_lib"
                           
echo "Creating query 'Alert On LAN Settings' in $query_lib..." 
wcrtquery -d "Alert On LAN Settings" -r "$1" -v UMA_VAlert_On_Lhhr \
   -c TME_OBJECT_LABEL \
   -c Retransmission_Int \
   -c Polling_Interval \
   -c Heartbeat_Interval \
   -c HWARE_VER \
   -c Alert_Destination \
   -c Auto_Clear_Events \
   -c Heartbeat_Enabled \
   -c HWARE_Enabled \
   -c Watchdog_Interval \
   -c Watchdog_Enabled \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Alert On LAN Settings"
sleep 2

echo "Creating query 'Alert Standard Format Settings' in $query_lib..." 
wcrtquery -d "Alert Standard Format Settings" -r "$1" -v UMA_VAlert_Stanhhi \
   -c TME_OBJECT_LABEL \
   -c AlertDestinationAd \
   -c MessageFormat \
   -c RetryCount \
   -c RetryInterval \
   -c ASFEnabled \
   -c PETsEnabled \
   -c HeartBeatsEnabled \
   -c RMCPEnabled \
   -c ASFWoLEnabled \
   -c FirmwareVersion \
   -c HeartbeatInterval \
   -c ASFSourceIP \
   -c MinPollingInterval \
   -c MinWatchdogResetVa \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Alert Standard Format Settings"
sleep 2

echo "Creating query 'AssetID' in $query_lib..." 
wcrtquery -d "AssetID" -r "$1" -v UMA_VAssetID \
   -c TME_OBJECT_LABEL \
   -c SYS_Name \
   -c SYS_Model \
   -c Product_Name \
   -c Deployment_Image_P \
   -c Deployment_Image_D \
   -c LCCM_Image_PRFL \
   -c LCCM_Image_Date \
   -c SYS_SER_Numb \
   -c SYS_GUID \
   -c SYS_Asset_Numbe \
   -c AssetID_Tag \
   -c Last_Inventoried \
   -c Purchase_Date \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "AssetID"
sleep 2

echo "Creating query 'BIOS Details' in $query_lib..." 
wcrtquery -d "BIOS Details" -r "$1" -v UMA_VBIOS_Details \
   -c TME_OBJECT_LABEL \
   -c BIOS_Manufacturer \
   -c BIOS_VER \
   -c BIOS_Release_Date \
   -c SUPP_SMBIOS \
   -c SMBIOS_Major_Versi \
   -c SMBIOS_Minor_Versi \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "BIOS Details"
sleep 2

echo "Creating query 'Cache' in $query_lib..." 
wcrtquery -d "Cache" -r "$1" -v UMA_VCache \
   -c TME_OBJECT_LABEL \
   -c level \
   -c SYS_Cache_Size \
   -c SYS_Cache_Write \
   -c Socket_Designation \
   -c Cache_Location \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Cache"
sleep 2

echo "Creating query 'CIM' in $query_lib..." 
wcrtquery -d "CIM" -r "$1" -v UMA_VCIM \
   -c TME_OBJECT_LABEL \
   -c CIM_VER \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "CIM"
sleep 2

echo "Creating query 'Firmware' in $query_lib..." 
wcrtquery -d "Firmware" -r "$1" -v UMA_VFirmware \
   -c TME_OBJECT_LABEL \
   -c Name \
   -c BIOS_Manufacturer \
   -c DESCRIP \
   -c BIOS_VER \
   -c BuildNum \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Firmware"
sleep 2

echo "Creating query 'FRU Service Numbers' in $query_lib..." 
wcrtquery -d "FRU Service Numbers" -r "$1" -v UMA_VFRU_Serviccnz \
   -c TME_OBJECT_LABEL \
   -c Name \
   -c FRUNum \
   -c IdentifyingNum \
   -c Vendor \
   -c RevisionLevel \
   -c DESCRIP \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "FRU Service Numbers"
sleep 2

echo "Creating query 'Geographic Information' in $query_lib..." 
wcrtquery -d "Geographic Information" -r "$1" -v UMA_VGeographicuj7 \
   -c TME_OBJECT_LABEL \
   -c Locale \
   -c Country_Code \
   -c OS_LANG \
   -c Code_Set \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Geographic Information"
sleep 2

echo "Creating query 'IBM Director Agent' in $query_lib..." 
wcrtquery -d "IBM Director Agent" -r "$1" -v UMA_VIBM_UM_Seroqd \
   -c TME_OBJECT_ID \
   -c TME_OBJECT_LABEL \
   -c Name \
   -c VER \
   -c Build_NUM \
   -c HTTPD_Port \
   -c SNMP_Traps_Enabled \
   -c Trap_Destinations \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "IBM Director Agent"
sleep 2

echo "Creating query 'IP Network Configuration' in $query_lib..." 
wcrtquery -d "IP Network Configuration" -r "$1" -v UMA_VIP_NET \
   -c TME_OBJECT_LABEL \
   -c IP_ADDR \
   -c IP_Subnet_Mask \
   -c IP_Gateway \
   -c DNS_Servers \
   -c DHCP_Enabled \
   -c DNS_Hostname \
   -c DNS_Domain \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "IP Network Configuration"
sleep 2

echo "Creating query 'IPX Network Configuration' in $query_lib..." 
wcrtquery -d "IPX Network Configuration" -r "$1" -v UMA_VIPX_Networc1c \
   -c TME_OBJECT_LABEL \
   -c IPX_Enabled \
   -c IPX_Frame_Type \
   -c IPX_ADDR \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "IPX Network Configuration"
sleep 2

echo "Creating query 'Lease Information' in $query_lib..." 
wcrtquery -d "Lease Information" -r "$1" -v UMA_VLease_Infoujc \
   -c TME_OBJECT_LABEL \
   -c Lessor \
   -c Lease_ST_Date \
   -c Lease_End_Date \
   -c Lease_Term_months \
   -c Lease_Amount \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Lease Information"
sleep 2

echo "Creating query 'Memory Details' in $query_lib..." 
wcrtquery -d "Memory Details" -r "$1" -v UMA_VMEM_Detf0m \
   -c TME_OBJECT_LABEL \
   -c DEV_Locator \
   -c siz \
   -c Form_Factor \
   -c Type \
   -c Speed \
   -c Data_Width \
   -c Total_Width \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Memory Details"
sleep 2

echo "Creating query 'Network Details' in $query_lib..." 
wcrtquery -d "Network Details" -r "$1" -v UMA_VNET_Def0l \
   -c TME_OBJECT_LABEL \
   -c NET_Adapter \
   -c NET_DRV \
   -c MAC_ADDR \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Network Details"
sleep 2

echo "Creating query 'Personalized Data' in $query_lib..." 
wcrtquery -d "Personalized Data" -r "$1" -v UMA_VPersonalizsq3 \
   -c TME_OBJECT_LABEL \
   -c Label1 \
   -c Data1 \
   -c Label2 \
   -c Data2 \
   -c Label3 \
   -c Data3 \
   -c Label4 \
   -c Data4 \
   -c Label5 \
   -c Data5 \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Personalized Data"
sleep 2

echo "Creating query 'Port Connectors' in $query_lib..." 
wcrtquery -d "Port Connectors" -r "$1" -v UMA_VPort_Conneoit \
   -c TME_OBJECT_LABEL \
   -c Logical_Name \
   -c Internal_Ports \
   -c Connector_Type \
   -c Port_Type \
   -c Tag \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Port Connectors"
sleep 2

echo "Creating query 'Processor Details' in $query_lib..." 
wcrtquery -d "Processor Details" -r "$1" -v UMA_VProcessor_f0j \
   -c TME_OBJECT_LABEL \
   -c Processor \
   -c Family \
   -c Clock_Speed \
   -c External_Clock_Spe \
   -c Max_Clock_Speed \
   -c Manufacturer \
   -c Processor_ID \
   -c Processor_Type \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Processor Details"
sleep 2

echo "Creating query 'Serial Number Information' in $query_lib..." 
wcrtquery -d "Serial Number Information" -r "$1" -v UMA_VSER_Numuj4 \
   -c TME_OBJECT_LABEL \
   -c Asset \
   -c SER_NUM \
   -c Manufacturer \
   -c Model \
   -c Type \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Serial Number Information"
sleep 2

echo "Creating query 'SNMP Agent Configuration' in $query_lib..." 
wcrtquery -d "SNMP Agent Configuration" -r "$1" -v UMA_VSNMP_Agentc1b \
   -c TME_OBJECT_LABEL \
   -c SNMP_Traps_Enabled \
   -c Trap_Destinations \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "SNMP Agent Configuration"
sleep 2

echo "Creating query 'System Board Configuration' in $query_lib..." 
wcrtquery -d "System Board Configuration" -r "$1" -v UMA_VSYS_Boac1d \
   -c TME_OBJECT_LABEL \
   -c String \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "System Board Configuration"
sleep 2

echo "Creating query 'System Enclosure' in $query_lib..." 
wcrtquery -d "System Enclosure" -r "$1" -v UMA_VSYS_Encyoe \
   -c TME_OBJECT_LABEL \
   -c Manufacturer \
   -c Type \
   -c Cabinet_Lock_Prese \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "System Enclosure"
sleep 2

echo "Creating query 'System Slots' in $query_lib..." 
wcrtquery -d "System Slots" -r "$1" -v UMA_VSYS_Slots \
   -c TME_OBJECT_LABEL \
   -c Slot_Type \
   -c Slot_Data_Bus_Widt \
   -c SUPP_Hot_Plug \
   -c Current_Usage \
   -c SlotDesignation \
   -c Shared_Slot_Openin \
   -c SUPP_PME_Signa \
   -c Tag \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "System Slots"
sleep 2

echo "Creating query 'User Details' in $query_lib..." 
wcrtquery -d "User Details" -r "$1" -v UMA_VUser_Details \
   -c TME_OBJECT_LABEL \
   -c User_Name \
   -c User_Phone \
   -c User_Department \
   -c User_Position \
   -c SYS_Location \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "User Details"
sleep 2

echo "Creating query 'Video Details' in $query_lib..." 
wcrtquery -d "Video Details" -r "$1" -v UMA_VVID_Details \
   -c TME_OBJECT_LABEL \
   -c Manufacturer \
   -c DESCRIP \
   -c Current_Vertical_R \
   -c Current_Horizontal \
   -c Current_NUM_of \
   -c VID_RAM_MEM_S \
   -c DRV_Filename \
   -c Current_Refresh_Ra \
   -c Color_Depth \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Video Details"
sleep 2

echo "Creating query 'Warranty Information' in $query_lib..." 
wcrtquery -d "Warranty Information" -r "$1" -v UMA_VWarranty_Iuj9 \
   -c TME_OBJECT_LABEL \
   -c Warranty_Duration \
   -c Warranty_End_Date \
   -c Warranty_Cost \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "Warranty Information"
sleep 2

echo "Creating query 'ServeRAID Controllers' in $query_lib..." 
wcrtquery -d "ServeRAID Controllers" -r "$1" -v UMA_VServeRAID_nj3 \
   -c TME_OBJECT_LABEL \
   -c DEV \
   -c Model \
   -c Manufacturer \
   -c Slot \
   -c BIOS_VER \
   -c Firmware_VER \
   -c DRV_VER \
   -c Stripe_Size \
   -c Initiator_IDs \
   -c Clustering \
   -c Cache_Battery_Stat \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "ServeRAID Controllers"
sleep 2

echo "Creating query 'ServeRAID Disk Drives' in $query_lib..." 
wcrtquery -d "ServeRAID Disk Drives" -r "$1" -v UMA_VServeRAID_9sh \
   -c TME_OBJECT_LABEL \
   -c DEV \
   -c ChannelID \
   -c CNTRL \
   -c Firmware \
   -c Capacity \
   -c Manufacturer \
   -c Model \
   -c FRU \
   -c SER_NUM \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "ServeRAID Disk Drives"
sleep 2

echo "Creating query 'ServeRAID Enclosures' in $query_lib..." 
wcrtquery -d "ServeRAID Enclosures" -r "$1" -v UMA_VServeRAID_14g \
   -c TME_OBJECT_LABEL \
   -c DEV \
   -c ChannelID \
   -c CNTRL \
   -c FirmwareLevel \
   -c Manufacturer \
   -c Model \
   -c SER_NUM \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "ServeRAID Enclosures"
sleep 2

echo "Creating query 'ServeRAID Logical Drives' in $query_lib..." 
wcrtquery -d "ServeRAID Logical Drives" -r "$1" -v UMA_VServeRAID_rx0 \
   -c TME_OBJECT_LABEL \
   -c LOG_DRV \
   -c CNTRL \
   -c ArrayID \
   -c RAID_Level \
   -c Data_Space \
   -c Install_Date \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "ServeRAID Logical Drives"
sleep 2

echo "Creating query 'RAID Controllers' in $query_lib..." 
wcrtquery -d "RAID Controllers" -r "$1" -v UMA_VRAID_Contrnj8 \
   -c TME_OBJECT_LABEL \
   -c DEV \
   -c Model \
   -c Manufacturer \
   -c Slot \
   -c BIOS_VER \
   -c Firmware_VER \
   -c DRV_VER \
   -c Stripe_Size \
   -c Initiator_IDs \
   -c Clustering \
   -c Cache_Battery_Stat \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "RAID Controllers"
sleep 2

echo "Creating query 'RAID Disk Drives' in $query_lib..." 
wcrtquery -d "RAID Disk Drives" -r "$1" -v UMA_VRAID_Disk_9sc \
   -c TME_OBJECT_LABEL \
   -c DEV \
   -c ChannelID \
   -c CNTRL \
   -c Firmware \
   -c Capacity \
   -c Manufacturer \
   -c Model \
   -c FRU \
   -c SER_NUM \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "RAID Disk Drives"
sleep 2

echo "Creating query 'RAID Enclosures' in $query_lib..." 
wcrtquery -d "RAID Enclosures" -r "$1" -v UMA_VRAID_Enclo14l \
   -c TME_OBJECT_LABEL \
   -c DEV \
   -c ChannelID \
   -c CNTRL \
   -c Firmware_Level \
   -c Manufacturer \
   -c Model \
   -c SER_NUM \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "RAID Enclosures"
sleep 2

echo "Creating query 'RAID Logical Drives' in $query_lib..." 
wcrtquery -d "RAID Logical Drives" -r "$1" -v UMA_VRAID_Logicrwv \
   -c TME_OBJECT_LABEL \
   -c LOG_DRV \
   -c CNTRL \
   -c ArrayID \
   -c RAID_Level \
   -c Data_Space \
   -c Install_Date \
   -w "order by TME_OBJECT_LABEL" \
"$query_lib" "RAID Logical Drives"
sleep 2
