#!/bin/sh
#  @(#)76    4.20  datasks.sh 
#
# Licensed Materials - Property of IBM
#
#
# (C) Copyright IBM Corp. 2003, 2004 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp
#
#  Version 4.20
#
#  This simple Bourne shell script creates a task library
#  containing the Shutdown and Reboot tasks. It must be run by
#  an administrator with proper TME authorization in the
#  appropriately configured TMR where the library must reside.
#  The following queries are created within the specified
#  query library (default is DIRECTOR_TASKS):
#
#
#  ./datasks.sh <HostMachineName> <PolicyRegionName> [TaskLibraryName]
#
# 'sleep 2' statements added as a workaround to query defect 
# to prevent transaction collisions.
#

# Usage statement
if [ $# -lt 2 ] ; then
        echo "Usage: $0 <HostMachineName> <PolicyRegionName> [TaskLibraryName]"
        exit 1
fi

if [ $# -eq 3 ] ; then
	task_lib="$3"
else
	task_lib='DIRECTOR_TASKS'
fi

mkdir $BINDIR/director
cp *.* $BINDIR/director

echo "Creating task library $task_lib in $2..."
wcrttlib "$task_lib" "$2"

echo "Creating task Reboot in $task_lib..." 
wcrttask -t "Reboot" \
         -l "$task_lib" \
         -r super:senior:user \
         -i w32-ix86 "$1" "$BINDIR/director/rebootDA.bat" \
         -i win95 "$1" "$BINDIR/director/rebootDA.bat" \
         -c "This task Reboots the selected subscribers"
sleep 2

echo "Creating task Shutdown in $task_lib..." 
wcrttask -t "Shutdown" \
         -l "$task_lib" \
         -r super:senior:user \
         -i w32-ix86 "$1" "$BINDIR/director/shutdownDA.bat" \
         -i win95 "$1" "$BINDIR/director/shutdownDA.bat" \
         -c "This task Shutsdown the selected subscribers"
sleep 2

echo "Creating task About in $task_lib..." 
wcrttask -t "About" \
         -l "$task_lib" \
         -r super:senior:user \
         -i default "$1" "$BINDIR/director/aboutDA.sh" \
         -c "This task Returns info about the installed Director Integration"
sleep 2

